.. image:: https://travis-ci.org/yunojuno/hipchat-notifications.svg?branch=master
    :target: https://travis-ci.org/yunojuno/hipchat-notifications

.. image:: https://badge.fury.io/py/hipchat-notifications.svg
    :target: https://badge.fury.io/py/hipchat-notifications

.. image:: https://codecov.io/gh/yunojuno/hipchat-notifications/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/yunojuno/hipchat-notifications

HipChat Notifications
=====================

Very simple library for sending notifications to HipChat via their v2 API.

Installation
------------

The library is available on PyPI as 'hipchat_notifications'

Tests
-----

The tests can be run using ``tox``:

.. code:: shell

    $ tox
